find_hash_factor_for_dictionary

Function find_hash_factor_for_dictionary 

pub fn find_hash_factor_for_dictionary(
    tokens: impl IntoIterator<Item = Vec<u8>>,
) -> u64
Find a suitable hash factor for a set of given tokens that prevents collisions when constructing a BytePairEncoding from those tokens.